﻿using DressAtelierContracts.BindingModels;
using DressAtelierContracts.BusinessLogicContracts;
using DressAtelierContracts.SearchModels;
using DressAtelierDataModels.Models;
using DressAtelierListImplement.Models;
using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SewingDresses
{
    public partial class FormAtelier : Form
    {
        private readonly ILogger _logger;
        private readonly IAtelierLogic _logic;
        private int? _id;
        public int ID { set { _id = value; } }
        public FormAtelier(ILogger<FormAtelier> logger, IAtelierLogic logic)
        {
            InitializeComponent();
            _logger = logger;
            _logic = logic;
        }

        private void FormAtelier_Load(object sender, EventArgs e)
        {
            if (_id.HasValue)
            {
                try
                {
                    _logger.LogInformation("Receiving atelier");
                    var view = _logic.ReadElement(new AtelierSearchModel
                    {
                        ID = _id.Value
                    });
                    if (view != null)
                    {
                        atelierNameTextBox.Text = view.Name;
                        atelierAddressTextBox.Text = view.Address;
                        dateTimePickerAtelier.Value = view.OpeningDate;
                        if (view.DressesList.Count != 0)
                        {
                            dataGridViewDresses.Rows.Clear();
                            foreach (var dress in view.DressesList)
                            {
                                dataGridViewDresses.Rows.Add(new object[] { dress.Key, dress.Value.Item1.DressName, dress.Value.Item2 });
                    }
                }
                    }
                }
                catch (Exception ex)
                {
                    _logger.LogError(ex, "Error receiving atelier");
                    MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void saveAtelierButton_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(atelierNameTextBox.Text) || string.IsNullOrEmpty(atelierAddressTextBox.Text))
            {
                MessageBox.Show("Fill all fields", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            Dictionary<int, (IDressModel, int)> dresses = new();
            if (_id.HasValue)
            {
                var atelier = _logic.ReadElement(new AtelierSearchModel { ID = _id });
                dresses = atelier.DressesList;
            }

            _logger.LogInformation("Saving atelier");
            try
            {
                var model = new AtelierBindingModel
                {
                    ID = _id ?? 0,
                    Name = atelierNameTextBox.Text,
                    Address = atelierAddressTextBox.Text,
                    OpeningDate = dateTimePickerAtelier.Value,
                    DressesList = dresses
                };
                var operationResult = _id.HasValue ? _logic.Update(model) : _logic.Create(model);
                if (!operationResult)
                {
                    throw new Exception("Error during saving. Extra info in logs.");
                }
                MessageBox.Show("Saving was succesful", "Message", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Error saving atelier");
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void cancelButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }
    }
}
