﻿using DressAtelierContracts.BindingModels;
using DressAtelierContracts.BusinessLogicContracts;
using DressAtelierContracts.SearchModels;
using DressAtelierDataModels.Models;
using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SewingDresses
{
    public partial class FormAtelierRestocking : Form
    {
        private readonly IAtelierLogic _logicAtelier;
        private readonly IDressLogic _logicDress;
        private readonly ILogger _logger;

        private int? _id;

        private Dictionary<int, (IDressModel, int)> _dressesList;
        public int ID { set { _id = value; } }
        public FormAtelierRestocking(ILogger<FormAtelierRestocking> logger, IAtelierLogic logicA,IDressLogic logicD)
        {
            InitializeComponent();
            _logicAtelier = logicA;
            _logger = logger;
            _logicDress = logicD;
            _dressesList = new Dictionary<int, (IDressModel, int)>();
        }

        private void FormAtelierRestocking_Load(object sender, EventArgs e)
        {
            _logger.LogInformation("Downloading dresses");
            try
            {
                var _list = _logicDress.ReadList(null);
                if (_list != null)
                {
                    dressComboBox.DisplayMember = "DressName";
                    dressComboBox.ValueMember = "ID";
                    dressComboBox.DataSource = _list;
                    dressComboBox.SelectedItem = null;
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Downloading dresses error");
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            _logger.LogInformation("Downloading ateliers");
            try
            {
                var _list = _logicAtelier.ReadList(null);
                if (_list != null)
                {
                    atelierComboBox.DisplayMember = "Name";
                    atelierComboBox.ValueMember = "ID";
                    atelierComboBox.DataSource = _list;
                    atelierComboBox.SelectedItem = null;
                }
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Downloading ateliers error");
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }

        private void ButtonSave_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(quantityTextBox.Text))
            {
                MessageBox.Show("Fill quantity field", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (dressComboBox.SelectedValue == null)
            {
                MessageBox.Show("Choose dress", "Error",
               MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (atelierComboBox.SelectedValue == null)
            {
                MessageBox.Show("Choose atelier", "Error",
               MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            
            _logger.LogInformation("Restocking of atelier");
            try
            {

                _logicAtelier.AddDress(new AtelierBindingModel
                {
                    ID = Convert.ToInt32(atelierComboBox.SelectedValue),
                    Name = atelierComboBox.Text
                },
                 new DressBindingModel
                 {
                     ID = Convert.ToInt32(dressComboBox.SelectedValue),
                     DressName = dressComboBox.Text,
                 }, Convert.ToInt32(quantityTextBox.Text));

                MessageBox.Show("Saving was succesfull", "Message", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Restrocking of atelier error");
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            
        }
    }
}
